@@ -4,10 +4,9 @@
 
 #pragma once
 
-
-#include <OSL/platform.h>
 #include <OSL/export.h>
 #include <OSL/oslversion.h>
+#include <OSL/platform.h>
 
 
 // All the things we need from Imath.
@@ -24,15 +23,31 @@
 #   include <OSL/Imathx/ImathVec.h>
 #   include <OSL/Imathx/ImathMatrix.h>
 #   include <OSL/Imathx/ImathColor.h>
-#   include <OSL/matrix22.h>
 #endif
 
-// The fmt library causes trouble for Cuda. Work around by disabling it from
-// oiio headers (OIIO <= 2.1) or telling fmt not to use the troublesome
-// int128 that Cuda doesn't understand (OIIO >= 2.2).
+// We included the Imath files we needed, so set the OIIO_IMATH_H_INCLUDED
+// symbol to prevent OpenImageIO/Imath.h from including them again (or
+// before), which is critical if they turn out to be different versions.
+#define OIIO_IMATH_H_INCLUDED 1
+
+
+// The fmt library causes trouble for Cuda. Work around by telling fmt not to
+// use the troublesome int128 that Cuda doesn't understand.
 #ifdef __CUDA_ARCH__
-#    define OIIO_USE_FMT 0
-#    define FMT_USE_INT128 0
+#    ifndef FMT_USE_INT128
+#        define FMT_USE_INT128 0
+#    endif
+#endif
+
+// For OSL internal compilation only, get deprecation warnings if we call OIIO
+// methods that use the old printf style interface.
+#ifdef OSL_INTERNAL
+#    ifdef OIIO_ERRORHANDLER_HIDE_PRINTF
+#        define OIIO_ERRORHANDLER_HIDE_PRINTF 1
+#    endif
+#    ifdef OIIO_HIDE_FORMAT
+#        define OIIO_HIDE_FORMAT 1
+#    endif
 #endif
 
 // All the things we need from OpenImageIO
@@ -47,6 +62,8 @@
 
 OSL_NAMESPACE_ENTER
 
+#define OSL_USE_BATCHED False
+
 /// Various compile-time defaults are defined here that could, in
 /// principle, be redefined if you are using OSL in some particular
 /// renderer that wanted things a different way.
@@ -73,11 +90,6 @@ using Color3   = Imath::Color3<Float>;
 using Matrix33 = Imath::Matrix33<Float>;
 using Matrix44 = Imath::Matrix44<Float>;
 
-#if OSL_USING_IMATH >= 3
-using Matrix22 = Imath::Matrix22<Float>;
-#else
-using Matrix22 = Imathx::Matrix22<Float>;
-#endif
 
 
 /// Assume that we are dealing with OpenImageIO's texture system.  It
@@ -89,13 +101,51 @@ using OIIO::TextureOpt;
 
 // And some other things we borrow from OIIO...
 using OIIO::ErrorHandler;
-using OIIO::TypeDesc;
 using OIIO::ustring;
 using OIIO::ustringHash;
 using OIIO::string_view;
 using OIIO::span;
 using OIIO::cspan;
 
+using OIIO::TypeDesc;
+using OIIO::TypeUnknown;
+using OIIO::TypeFloat;
+using OIIO::TypeColor;
+using OIIO::TypePoint;
+using OIIO::TypeVector;
+using OIIO::TypeNormal;
+using OIIO::TypeMatrix;
+using OIIO::TypeFloat4;
+using OIIO::TypeString;
+using OIIO::TypeInt;
+using OIIO::TypeFloat2;
+using OIIO::TypeVector2;
+using OIIO::TypeVector4;
+
+using OIIO::Strutil::print;
+
+template<typename Str, typename... Args>
+OSL_NODISCARD inline std::string
+fmtformat(const Str& fmt, Args&&... args)
+{
+    return OIIO::Strutil::fmt::format(fmt, std::forward<Args>(args)...);
+}
+
+
+
+// N.B. SymArena is not really "configuration", but we cram it here for
+// lack of a better home.
+
+/// The different memory arenas where symbols may live on the app side
+enum class SymArena {
+    Unknown = 0,        // Unknown/uninitialized value
+    Absolute,           // Absolute address
+    Heap,               // Belongs to context heap
+    Outputs,            // Belongs to output arena
+    UserData,           // UserData arena
+    // ShaderGlobals,   // RESERVED
+};
+
 
 
 /////////////////////////////////////////////////////////////////////////
@@ -120,47 +170,14 @@ using OIIO::cspan;
 
 namespace pvt {
 
-#if (OSL_CPLUSPLUS_VERSION >= 14)
-    template<int... IntegerListT>
-    using int_sequence = std::integer_sequence<int, IntegerListT...>;
+template<int... IntegerListT>
+using int_sequence = std::integer_sequence<int, IntegerListT...>;
 
-    template<int EndBeforeT>
-    using make_int_sequence =  std::make_integer_sequence<int, EndBeforeT>;
+template<int EndBeforeT>
+using make_int_sequence =  std::make_integer_sequence<int, EndBeforeT>;
 
-    template<bool... BoolListT >
-    using bool_sequence = std::integer_sequence<bool, BoolListT... >;
-#else
-    // std::integer_sequence requires c++14 library support,
-    // we have our own version here in case the environment is c++14 compiler
-    // building against c++11 library.
-    template<int... IntegerListT>
-    struct int_sequence
-    {
-    };
-
-    template<int StartAtT, int EndBeforeT, typename IntSequenceT>
-    struct int_sequence_generator;
-
-    template<int StartAtT, int EndBeforeT, int... IntegerListT>
-    struct int_sequence_generator<StartAtT, EndBeforeT, int_sequence<IntegerListT...>>
-    {
-        typedef typename int_sequence_generator<StartAtT+1, EndBeforeT, int_sequence<IntegerListT..., StartAtT>>::type type;
-    };
-
-    template<int EndBeforeT, int... IntegerListT>
-    struct int_sequence_generator<EndBeforeT, EndBeforeT, int_sequence<IntegerListT...>>
-    {
-        typedef int_sequence<IntegerListT...> type;
-    };
-
-    template<int EndBeforeT>
-    using make_int_sequence = typename int_sequence_generator<0, EndBeforeT, int_sequence<> >::type;
-
-    template<bool... BoolListT >
-    struct bool_sequence
-	{
-	};
-#endif
+ template<bool... BoolListT >
+using bool_sequence = std::integer_sequence<bool, BoolListT... >;
 
 #if (OSL_CPLUSPLUS_VERSION >= 17)
     template<class... ListT>
@@ -194,21 +211,8 @@ static OSL_FORCEINLINE OSL_HOSTDEVICE void static_foreach(const FunctorT &iFunct
     static_foreach<ConstantWrapperT>(pvt::make_int_sequence<N>(), iFunctor);
 }
 
-#if (OSL_CPLUSPLUS_VERSION >= 14)
-    template<int N>
-    using ConstIndex = std::integral_constant<int, N>;
-#else
-    template<int N>
-    struct ConstIndex : public std::integral_constant<int, N>
-    {
-        // C++14 adds this conversion operator we need to allow non-generic
-        // lambda functions (pre C++14) to accept an "int" instead of a
-        // typed ConstIndex<N> with "auto"
-        constexpr int operator()() const noexcept {
-            return N;
-        }
-    };
-#endif
+template<int N>
+using ConstIndex = std::integral_constant<int, N>;
 
 
 // During development it can be useful to output extra information
